/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "pokerplayerui.h"

void pokerPlayerUiInit(pokerplayerui_t *ui) {
  labelInit(&ui->label);
}

void pokerPlayerUiRender(
  pokerplayerui_t *ui, pokergame_t *game, shader_t *shader, font_t *font,
  int32_t playerIndex, float x, float y
) {
  pokerplayer_t *player;
  char buffer[32];
  float scale;

  scale = fontGetScale(FONT_SIZE_DEFAULT);
  player = game->poker.players + playerIndex;

  // Render chips
  sprintf(buffer, "$%i", player->chips);
  labelSetText(&ui->label, font, buffer);
  labelRender(&ui->label, shader, x - ui->label.info.width, y);

  // Render Face

  // Render state
  if(player->state & POKER_PLAYER_STATE_OUT) {
    sprintf(buffer, "Out");
  } else if(player->state & POKER_PLAYER_STATE_FOLDED) {
    sprintf(buffer, "Folded");
  } else if(player->state & POKER_PLAYER_STATE_SHOWING) {
    sprintf(buffer, "Showing");
  } else if(game->poker.bet.better == playerIndex) {
    sprintf(buffer, "Thinking");
  } else {
    sprintf(buffer, "Whatever");
  }
  labelSetText(&ui->label, font, buffer);
  labelRender(&ui->label, shader,
    x - ui->label.info.width, y + scale * FONT_LINE_HEIGHT
  );
}

void pokerPlayerUiDispose(pokerplayerui_t *ui) {
  labelDispose(&ui->label);
}